/*
    Sample solution for Extended Manhattan Distance
    Steven J Zeil
 */

#include <algorithm>
#include <iomanip>
#include <iostream>
#include <cmath>
#include <limits>
#include <vector>

#include <point.h>
#include <line.h>

using namespace std;




Point cityLL;
Point cityUR;
Point p1;
Point p2;


bool bounded (double v, double v1, double v2)
{
  return (v != std::numeric_limits<double>::max()
	  && ((v >= v1 && v <= v2)
	      || (v >= v2 && v <= v1)));
}



double totalDist (const Line& candidate)
{
  return p1.euclideanDist(candidate.p1)
    + candidate.p1.manhattanDist(candidate.p2)
    + candidate.p2.euclideanDist(p2);
}


bool isOnEdge (const Point& p, const Point& closeTo)
{
  if (((p.x == cityLL.x && closeTo.x <= cityLL.x)
       || (p.x == cityUR.x && closeTo.x >= cityUR.x))
      &&  (p.y >= cityLL.y && p.y <= cityUR.y))
    return true;
  if (((p.y == cityLL.y && closeTo.y <= cityLL.y)
       || (p.y == cityUR.y && closeTo.y >= cityUR.y))
      &&  (p.x >= cityLL.x && p.x <= cityUR.x))
    return true;
  return false;
}


bool tryMoving (int dx1, int dy1, int dx2, int dy2,
		Line& candidate, double& bestDist)
{
  Point p (candidate.p1.x + dx1, candidate.p1.y + dy1);
  Point q (candidate.p2.x + dx2, candidate.p2.y + dy2);
  if (isOnEdge(p, p1) && isOnEdge(q, p2))
    {
      Line newCandidate (p,q);
      double dist = totalDist (newCandidate);
      if (dist < bestDist)
	{
	  bestDist = dist;
	  candidate = newCandidate;
	  return true;
	}
    }
  return false;
}



double solve()
{
  Line candidate;
  // A candidate solution c is two points c.p1 and c.p2 such that
  // we move directly from p1 to c.p1, horizontally and vertically from 
  // c.p1 to c.p2, and directly from c.p2 to p2

  bool candidateFound = false;
  double bestDist = 1000000.0;

  Point cityUL (cityLL.x, cityUR.y);
  Point cityLR (cityUR.x, cityLL.y);
  Line border[] = {Line(cityLL, cityLR), Line(cityLR, cityUR), 
		   Line(cityUR, cityUL), Line(cityUL, cityLL) };


  Line directPath (p1, p2);

  // Are both points within the city?
  if (bounded(p1.x, cityLL.x, cityUR.x)
      && bounded(p2.x, cityLL.x, cityUR.x)
      && bounded(p1.y, cityLL.y, cityUR.y)
      && bounded(p2.y, cityLL.y, cityUR.y))
    {
      candidate = Line(p1, p2);
      candidateFound = true;
    }

  if (!candidateFound)
    {
      // Is p2 inside the city and p1 outside?
      if (bounded(p2.x, cityLL.x, cityUR.x)
	  && bounded(p2.y, cityLL.y, cityUR.y))
	swap (p1, p2);

      // Is p1 inside the city and p2 outside?
      if (bounded(p1.x, cityLL.x, cityUR.x)
	  && bounded(p1.y, cityLL.y, cityUR.y))
	for (int i = 0; i < 4; i++)
	  {
	    if (directPath.crossesSegment(border[i])
		&& border[i].crossesSegment(directPath))
	      {
		Line cand;
		if (border[i].p1.x == border[i].p2.x)
		  cand = Line(p1, Point(border[i].p1.x, p1.y));
		else
		  cand = Line(p1, Point(p1.x, border[i].p1.y));
		double d = totalDist(cand);
		if (d < bestDist)
		  {
		    candidate = cand;
		    bestDist = d;
		    candidateFound = true;
		  }
	      }
	  }
    }


  if (!candidateFound)
    {
      // Check for lines that cross opposite sides of the city
      for (int i = 0; i < 4 && !candidateFound; i++)
	{
	  int j = (i + 2) % 4;
	  if (directPath.crossesSegment(border[i])
	      && directPath.crossesSegment(border[j]))
	    {
	      // Have to be careful - the actual midpoint might lie between
	      // two intersection points of the grid
	      Point intersecti;
	      Point intersectj;
	      if (border[i].p1.x == border[i].p2.x) 
		{
		  // crossing vertical borders
		  intersecti =  Point (border[i].p1.x,
				       (int)directPath.y(border[i].p1.x));
		  intersectj =  Point (border[j].p1.x,
				       (int)directPath.y(border[j].p1.x));
		}
	      else
		{
		  // crossing horizontal borders
		  intersecti =  Point ((int)directPath.x(border[i].p1.y),
				       border[i].p1.y);
		  intersectj =  Point ((int)directPath.x(border[j].p1.y),
				       border[j].p1.y);
		}
	      if (p1.euclideanDist(intersecti) > p1.euclideanDist(intersectj))
		swap (intersecti, intersectj);
	      candidate = Line(intersecti, intersectj);
	      candidateFound = true;
	    }
	}
    }

  // Check for lines that cross two adjacent borders of the city (or one corner)
  if (!candidateFound)
    {
      for (int i = 0; i < 4 && !candidateFound; i++)
	{
	  int j = (i + 1) % 4;
	  if (directPath.crossesSegment(border[i])
	      && directPath.crossesSegment(border[j]))
	    {
	      Point p = border[i].p2;
	      candidate = Line(p,p);
	      candidateFound = true;
	    }
	}
    }

  
  // If none of the above cases holds, there must be a direct line
  // between the points that does not intersect the city.
  if (!candidateFound)
    {
      candidate = Line(p2, p2);
      return totalDist(candidate);
    }

  
  // Because of round-off errors, we might be slightly off. Try moving
  //  around a bit to hit the min distance. (This also makes the algorithm 
  //  a bit more robust if we've made minor messups in a case.
  bestDist = totalDist(candidate);
  bool moved = true;
  while (moved)
    {
      moved = false;
      cerr << p1 << "=>" << candidate.p1 << "=>" << candidate.p2 
	   << "=>" << p2 << ": " << bestDist << endl;
      moved = tryMoving (-1, 0, 0, 0, candidate, bestDist);
      moved |= tryMoving (1, 0, 0, 0, candidate, bestDist);
      moved |= tryMoving (0, -1, 0, 0, candidate, bestDist);
      moved |= tryMoving (0, 1, 0, 0, candidate, bestDist);
      moved |= tryMoving (0, 0, -1, 0, candidate, bestDist);
      moved |= tryMoving (0, 0, 1, 0, candidate, bestDist);
      moved |= tryMoving (0, 0, 0, -1, candidate, bestDist);
      moved |= tryMoving (0, 0, 0, 1, candidate, bestDist);
    }
  cerr << p1 << "=>" << candidate.p1 << "=>" << candidate.p2 
       << "=>" << p2 << ": " << bestDist << endl;

  return bestDist;
}




int main (int argc, char** argv)
{
  
  while (cin >> cityLL.x)
    {
      cin >> cityLL.y;
      cin >> cityUR.x >> cityUR.y;
      if (cityLL.x == cityUR.x)
    	  break;
      cin >> p1.x >> p1.y;
      cin >> p2.x >> p2.y;
      cout << fixed << setprecision(2) << solve() << endl;
    }
  return 0;
}
